@@ -258,6 +258,38 @@ struct GlobalObjectId {
   return rc;
 }
 
+//
+//
+//
+- (NSString *) _personalNameFrom: (NSArray *) enveloppeAddresses
+{
+  NGImap4EnvelopeAddress *address;
+  NSString *email, *rc, *name;
+  NSMutableArray *addresses;
+  int i, max;
+
+  rc = nil;
+  max = [enveloppeAddresses count];
+
+  if (max > 0)
+    {
+      addresses = [NSMutableArray array];
+      for (i = 0; i < max; i++)
+        {
+          address = [enveloppeAddresses objectAtIndex: i];
+          name = [address personalName];
+          email = [NSString stringWithFormat: @"%@", (name ? name : [address baseEMail])];
+
+          if (email)
+            [addresses addObject: email];
+        }
+      rc = [addresses componentsJoinedByString: @";"];
+    }
+
+  return rc;
+}
+
+
 //
 //
 //
@@ -859,7 +891,13 @@ struct GlobalObjectId {
   // If there are multiple e-mail addresses, they are separated by commas."
   value = [self _emailAddressesFrom: [[self envelope] to]];
   if (value)
-    [s appendFormat: @"<To xmlns=\"Email:\">%@</To>", [value activeSyncRepresentationInContext: context]];
+    {
+      [s appendFormat: @"<To xmlns=\"Email:\">%@</To>", [value activeSyncRepresentationInContext: context]];
+      // DisplayTo - If there are multiple display names, they are separated by semi-colons.
+      value = [self _personalNameFrom: [[self envelope] to]];
+      if (value)
+        [s appendFormat: @"<DisplayTo xmlns=\"Email:\">%@</DisplayTo>", [value activeSyncRepresentationInContext: context]];
+    }
 
   // From
   value = [self _emailAddressesFrom: [[self envelope] from]];
@@ -881,9 +919,6 @@ struct GlobalObjectId {
   else
     [s appendFormat: @"<DateReceived xmlns=\"Email:\">%@</DateReceived>", [[NSDate date] activeSyncRepresentationInContext: context]];
 
-  // DisplayTo
-  [s appendFormat: @"<DisplayTo xmlns=\"Email:\">%@</DisplayTo>", [[context activeUser] login]];
-  
   // Cc - same syntax as the To field
   value = [self _emailAddressesFrom: [[self envelope] cc]];
   if (value)
