@@ -380,10 +380,31 @@ static GCSStringFormatter *stringFormatter = nil;
 
 - (NSString *) _sqlForQualifier: (EOQualifier *) qualifier
 {
+  static EOAdaptor *adaptor = nil;
   NSMutableString *ms;
 
   if (qualifier)
     {
+      if (!adaptor)
+        {
+          EOAdaptorContext *adaptorCtx;
+          EOAdaptorChannel *channel;
+          channel = [self acquireStoreChannel];
+          adaptorCtx = [channel adaptorContext];
+          adaptor = [adaptorCtx adaptor];
+        }
+
+      if ([qualifier isKindOfClass: [EOAndQualifier class]])
+        [self _findQualifiers: (id)qualifier withAdaptor: adaptor];
+      else if ([qualifier isKindOfClass: [EOOrQualifier class]])
+        [self _findQualifiers: (id)qualifier withAdaptor: adaptor];
+      else if ([qualifier isKindOfClass: [EOKeyValueQualifier class]])
+        [self _formatQualifierValue: (EOKeyValueQualifier *)qualifier withAdaptor: adaptor];
+      else if ([qualifier isKindOfClass: [EONotQualifier class]])
+        [self _formatQualifierValue: (EOKeyValueQualifier *)[(id)qualifier qualifier] withAdaptor: adaptor];
+      else
+        [self errorWithFormat:@"unknown qualifier: %@", qualifier];
+
       ms = [NSMutableString stringWithCapacity:32];
       [qualifier _gcsAppendToString: ms];
     }
@@ -393,6 +414,51 @@ static GCSStringFormatter *stringFormatter = nil;
   return ms;
 }
 
+- (void) _findQualifiers: (id) qualifier
+             withAdaptor: (EOAdaptor *) adaptor
+{
+  NSArray *qs;
+  unsigned i, count;
+
+  if (qualifier == nil) return;
+
+  qs = [qualifier qualifiers];
+  if ((count = [qs count]) == 0)
+    return;
+
+  for (i = 0; i < count; i++) {
+    id q = [qs objectAtIndex: i];
+    if ([q isKindOfClass: [EOAndQualifier class]])
+      [self _findQualifiers: q withAdaptor: adaptor];
+    else if ([q isKindOfClass:[EOOrQualifier class]])
+      [self _findQualifiers: q withAdaptor: adaptor];
+    else if ([q isKindOfClass:[EOKeyValueQualifier class]])
+      [self _formatQualifierValue: (EOKeyValueQualifier *)q withAdaptor: adaptor];
+    else if ([q isKindOfClass:[EONotQualifier class]])
+      [self _formatQualifierValue: (EOKeyValueQualifier *)[q qualifier] withAdaptor: adaptor];
+    else
+      [self errorWithFormat:@"unknown qualifier: %@", q];
+  }
+}
+
+- (void) _formatQualifierValue: (EOKeyValueQualifier *) qualifier
+                   withAdaptor: (EOAdaptor *) adaptor
+{
+  NSString *field;
+  EOAttribute *attribute;
+  NSString *formattedValue;
+
+  field = [qualifier key];
+  attribute = [self _attributeForColumn: field];
+  if (attribute)
+    {
+      formattedValue = [adaptor formatValue: [qualifier value]
+                               forAttribute: attribute];
+      [qualifier setValue: formattedValue];
+      [qualifier setFormatted: YES];
+    }
+}
+
 - (NSString *)_sqlForSortOrderings:(NSArray *)_so {
   NSMutableString *sql;
   unsigned i, count;
