@@ -260,22 +260,6 @@ static memcached_st *handle = NULL;
   return [users objectForKey: name];
 }
 
-- (void) registerGroup: (SOGoGroup *) group
-              withName: (NSString *) groupName
-	      inDomain: (NSString *) domainName
-
-{
-  if (group)
-    [groups setObject: group forKey: [NSString stringWithFormat: @"%@+%@", groupName, domainName]];
-}
-
-- (id) groupNamed: (NSString *) groupName
-	 inDomain: (NSString *) domainName
-
-{
-  return [groups objectForKey: [NSString stringWithFormat: @"%@+%@", groupName, domainName]];
-}
-
 - (void) registerIMAP4Connection: (NGImap4Connection *) connection
                           forKey: (NSString *) key
 {
